==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragEndEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneDragEndEventArgsDescriptionMetadata, _super);
    function WebPaneDragEndEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragEndEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
            WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneDragEndEventArgsDescriptionMetadata.a);
        WebPaneDragEndEventArgsDescriptionMetadata.d(a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
        a.item("Detail", "ExportedType:WebPaneDragEndEventArgs");
    };
    WebPaneDragEndEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragEndEventArgsDescriptionMetadata.b(a);
        a.u("WebPaneDragEndEventArgs", function () { return new WebPaneDragEndEventArgsDescription(); });
        a.t("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragEndEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragEndEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneDragEndEventArgsDescriptionMetadata, _super);
    function WebPaneDragEndEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragEndEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
            WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneDragEndEventArgsDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
    };
    WebPaneDragEndEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragEndEventArgsDescriptionMetadata.b(a);
        a.u("WebPaneDragEndEventArgs", function () { return new WebPaneDragEndEventArgsDescription(); });
        a.t("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragEndEventArgsDescriptionMetadata };
